@@ -13,11 +13,11 @@ import os
 import shutil
 import sys
 from multiprocessing import cpu_count
-from snakemake.dag import Batch
 
 import snakemake
 import yaml
 from psutil import virtual_memory
+from snakemake.dag import Batch
 
 from haystac import __version__
 from haystac.workflow.scripts.entrez_utils import (
@@ -717,7 +717,7 @@ The haystac commands are:
 
         optional.add_argument(
             "--min-prob",
-            help="Minimum posterior probability to assign an aligned read to a given species (default: 0.50)",
+            help="Minimum posterior probability to assign an aligned read to a given species (default: 0.75)",
             type=FloatRangeType(0, 100),
             metavar="<float>",
             default=argparse.SUPPRESS,
@@ -725,7 +725,7 @@ The haystac commands are:
 
         optional.add_argument(
             "--mismatch-probability",
-            help="Base mismatch probability (default: 0.15)",
+            help="Base mismatch probability (default: 0.05)",
             type=FloatRangeType(0.01, 0.5),
             metavar="<float>",
             default=argparse.SUPPRESS,
@@ -928,7 +928,10 @@ The haystac commands are:
                 print(" " + target)
             print("\n")
 
-        os.makedirs(SNAKE_DIR, exist_ok=True)
+        try:
+            os.makedirs(SNAKE_DIR, exist_ok=True)
+        except PermissionError:
+            print_error("Cannot write to the current working directory.")
 
         # save the run-time config file
         with open(CONFIG_RUNTIME, "w") as fout:
